/********************************************************************/
/* File: BLDGLIX.SQL                                                */
/*                                                                  */
/* Description:                                                     */
/*   This file contains stored procedures for building and          */
/*   maintaining the FRx server-based GL index.                     */
/*                                                                  */
/********************************************************************/

/************************************************/
/* frlUpdateAcctCode                            */
/************************************************/



IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id('frlUpdateAcctCode'))
	DROP PROC frlUpdateAcctCode
go
CREATE PROC frlUpdateAcctCode @EntityNum smallint, @ProcessSet char(8), @Structure char(8), @NatSegNum tinyint, @MaxSegs tinyint,				@CompSegNum smallint, @EntityCode char(16)
AS 
BEGIN



	DECLARE
		@i					smallint,
		@j					smallint,
		@Pos				smallint,
		@Start			smallint,
		@Length			smallint,
		@NatStart		smallint,
		@NatLen			smallint,
		@PreStart		smallint,
		@PreLen			smallint,
		@PostStart		smallint,
		@PostLen			smallint
	
	

	/* Reset the row counter to make sure we process all records */
	SET RowCount 0

	/* Build segment information temporary table */
	CREATE TABLE #frl_segs (
		seg_num		tinyint,
		seg_length	tinyint,
		seg_start	tinyint
	)

	SELECT	@Pos = 1, @i = 1
	WHILE @i <= @MaxSegs
	BEGIN
		INSERT	#frl_segs
		SELECT	@i, seg_length, @Pos
		FROM		frl_seg_ctrl
		WHERE		entity_num = @EntityNum
		AND		seg_num = @i

		SELECT	@Pos = @Pos + seg_length
		FROM		frl_seg_ctrl
		WHERE		entity_num = @EntityNum
		AND		seg_num = @i

		SELECT	@i = @i + 1
	END /* WHILE */



	/*  next line was just for debuggin  */
	/*  insert frl_temp  select @CompSegNum,@CompSegStart, @CompSegLen, @EntityCode  */

	/* Insert frl_acct_code record for all account codes */


	/* Insert frl_acct_code record for all account codes */
	INSERT	frl_acct_code(
				acct_id, entity_num, acct_code, acct_type,
				acct_status, acct_desc, normal_bal,
				bal_sheet_acct, nat_seg_code, rollup_level)
	SELECT	ACCT_INT_CODE, @EntityNum, ACCT_CODE, ACCT_TYPE,
				0, ACCT_DESC, 0,
				0, ACCT_CODE, ROLL_DEPTH
	FROM		ACCT
	WHERE		ACCT_CODE > ''	/* Allow the query optimizer TO pick the clustered index */
	AND		STRT_CODE = @Structure
	AND		FLX_PRS_OWNER = @ProcessSet


	/* Update the nat_seg_code if nat_seg_code segment is not 1 */
	IF (@NatSegNum <> 1)
	BEGIN
		SELECT @i = 1, @PreLen = 0, @PostLen = 0
		WHILE @i <= @MaxSegs
		BEGIN
			SELECT	@Start = seg_start, @Length = seg_length
			FROM		#frl_segs
			WHERE		seg_num = @i

			IF @i < @NatSegNum
			BEGIN
				SELECT @PreStart =ISNULL(@PreStart,@Start)
				SELECT @PreLen = @PreLen + @Length
			END
			ELSE IF @i > @NatSegNum
			BEGIN
				SELECT @PostStart =ISNULL(@PostStart, @Start)
				SELECT @PostLen = @PostLen + @Length
			END
			ELSE
			BEGIN
				SELECT @NatStart = @Start
				SELECT @NatLen = @Length
			END
			
			SELECT	@i = @i + 1
		END /* WHILE */

		UPDATE	frl_acct_code
		SET		nat_seg_code =
					substring(acct_code, @NatStart, @NatLen) +
					substring(acct_code, @PreStart, @PreLen) +
					substring(acct_code, @PostStart, @PostLen)
		FROM		frl_acct_code
            WHERE       entity_num = @EntityNum
	END

	/* Reset bal_sheet_acct and normal_bal flag */
	UPDATE	frl_acct_code
	SET		bal_sheet_acct = 1
	WHERE		acct_type < 3
	AND		entity_num = @EntityNum

	UPDATE	frl_acct_code
	SET		normal_bal = 1
	WHERE		acct_type BETWEEN 1 AND 3
	AND		entity_num = @EntityNum

	/* Insert frl_acct_seg records */
	SELECT @i = 2
	WHILE @i <= @MaxSegs
	BEGIN
		IF @i <> @NatSegNum
		BEGIN
					SELECT @j = 2
			SELECT @PreStart = 0, @NatStart = 0, @PostStart = 0
			SELECT @PreLen = 0, @NatLen = 0, @PostLen = 0
			WHILE @j <= @MaxSegs
			BEGIN
				IF @j <> @NatSegNum
				BEGIN
					SELECT	@Start = seg_start, @Length = seg_length
					FROM		#frl_segs
					WHERE		seg_num = @j

					IF @j < @i
					BEGIN
						IF @PreStart = 0 SELECT @PreStart = @Start
						SELECT @PreLen = @PreLen + @Length
					END
					ELSE IF @j > @i
					BEGIN
						IF @PostStart = 0 SELECT @PostStart = @Start
						SELECT @PostLen = @PostLen + @Length
					END
					ELSE
					BEGIN
						SELECT @NatStart = @Start
						SELECT @NatLen = @Length
					END
				END
				SELECT	@j = @j + 1
			END /* WHILE */

			INSERT	frl_acct_seg
			SELECT	@EntityNum, acct_id, @i,
						substring(acct_code, @NatStart, @NatLen) +
						substring(acct_code, @PreStart, @PreLen) +
						substring(acct_code, @PostStart, @PostLen),
						acct_code
			FROM		frl_acct_code
                  WHERE       entity_num = @EntityNum

		END /* IF @i <> @NatSegNum */
		SELECT	@i = @i + 1
	END /* WHILE */
END /* PROC frlUpdateAcctCode */
go

GRANT EXECUTE ON frlUpdateAcctCode TO PUBLIC
go

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id('frlBuildSegDesc'))
  DROP PROC frlBuildSegDesc
go
CREATE PROC frlBuildSegDesc @EntityNum smallint, @ProcessSet char(8), @Structure char(8)
AS
BEGIN



  DECLARE @MaxSegs tinyint,
	  @i tinyint,
	  @fInNatSeg tinyint,
	  @fInsertSegCtrl tinyint,
	  @SegNum tinyint,
	  @NatSegNum tinyint,
	  @RealSeg tinyint,
	  @Category tinyint,
	  @KeepDeleting tinyint,  
	  @ElmCode char(8),
          @SegCtrl tinyint,
	  @ElmValdte tinyint,
          @SegLength tinyint,
          @RespStart tinyint,
          @Finished tinyint,
	  @SegCode varchar(64),
	  @DefnDesc char(60),
	  @AcctAbbr char(8),
          @RespCount tinyint
declare @fFirstType0 int
declare @fFirstType2 int
set @fFirstType0=0
set @fFirstType2 =0

  /* Find the max segments */
  SELECT @i = 1,
	 @fInNatSeg = 0,
	 @fInsertSegCtrl = 0,
	 @SegNum = 0,
         @RespStart = 1,
         @RespCount = 1,
	 @MaxSegs = max(A.ELM_DSP_ORDER)
    FROM STEL A, ELMT B
   WHERE A.FLX_PRS_OWNER = @ProcessSet
     AND A.STRT_CODE = @Structure
     AND A.ELM_CODE = B.ELM_CODE
     AND A.FLX_PRS_OWNER = B.FLX_PRS_OWNER


  CREATE TABLE #frl_real_segs (new_seg tinyint, old_seg tinyint) 

  WHILE @i <= @MaxSegs
    BEGIN
      SELECT @SegCtrl = 0
      SELECT @Category = B.ELM_CATG
	FROM STEL A, ELMT B
       WHERE A.FLX_PRS_OWNER = @ProcessSet
	 AND A.STRT_CODE = @Structure
	 AND A.ELM_DSP_ORDER = @i
	 AND A.ELM_CODE = B.ELM_CODE
	 AND A.FLX_PRS_OWNER = B.FLX_PRS_OWNER

	  IF @Category = 1
		select @SegNum=@SegNum+1
		
      IF @Category = 2
    	BEGIN
			if @fFirstType2 =0 
				begin
				select @fFirstType2 =1
				select @SegNum=@SegNum+1
				end
 		END	
       

	IF @Category = 0
    	BEGIN
		
		IF @fFirstType0 =0 
			SELECT @fFirstType0 =1,@SegNum=@SegNum+1
 		END	
		
	  INSERT #frl_real_segs values (@SegNum, @i)
	select @i =@i+1
end

  SELECT @MaxSegs = @SegNum

  SET RowCount 2500
  SELECT @KeepDeleting = 1
  WHILE @KeepDeleting = 1
  BEGIN
    BEGIN tran
      DELETE FROM frl_seg_desc
       WHERE entity_num = @EntityNum
      IF @@RowCount = 0
	SELECT @KeepDeleting = 0
    commit tran
  END

  /* Filling in frl_seg_desc */
  CREATE TABLE #frl_seg_desc
  ( SEG_CODE varchar(64) NULL,
    DEFN_DESC char(60) NULL, 
    ACCT_ABBR    char(8) NULL)

  SELECT @i = 1

  WHILE @i <= @MaxSegs
    BEGIN
      SELECT @RealSeg = old_seg
	FROM #frl_real_segs
       WHERE new_seg = @i

      SELECT @Category = B.ELM_CATG,
	     @ElmCode = B.ELM_CODE,
	     @ElmValdte = B.ELM_VALDTE
	FROM STEL A, ELMT B
       WHERE A.FLX_PRS_OWNER = @ProcessSet
	 AND A.STRT_CODE = @Structure
	 AND A.ELM_CODE = B.ELM_CODE
	 AND A.FLX_PRS_OWNER = B.FLX_PRS_OWNER
	 AND A.ELM_DSP_ORDER = @RealSeg

      /* IF category 0 (company) or 1 (responsibility) */
      IF @Category = 0 or @Category = 1
        BEGIN
          /* IF the element is validated, pull values FROM ELVA. */
          IF @ElmValdte = 2
            BEGIN
	      BEGIN tran
	      INSERT INTO frl_seg_desc
	        (entity_num, seg_num, seg_code, seg_code_desc, seg_short_desc)
	        SELECT @EntityNum, @i, ELM_VALUE, ELM_DESC, ELM_DESC
	        FROM ELVA
	       WHERE FLX_PRS_OWNER = @ProcessSet
	         AND ELM_CODE = @ElmCode
 	      commit tran
              IF @Category = 1
                BEGIN
                  SELECT @SegLength = seg_length
                    FROM frl_seg_ctrl
                   WHERE entity_num = @EntityNum
                     AND seg_num = @i
                  SELECT @RespStart = @RespStart + @SegLength
                END 
	    END
          else
            BEGIN
              /* IF the element is not validated AND the category is company (0) */
              /* pull values FROM COMP. */
              IF @Category = 0
                BEGIN
	          BEGIN tran
	          INSERT INTO frl_seg_desc
	            (entity_num, seg_num, seg_code, seg_code_desc, seg_short_desc)
	            SELECT @EntityNum, @i, COMP_CODE, DEFN_DESC, COMP_ABBR
	              FROM COMP
	             WHERE FLX_PRS_OWNER = @ProcessSet
	          commit tran
                END
              else
                BEGIN

                  /* Get segment length FROM frl_seg_ctrl */
                  SELECT @SegLength = seg_length
                    FROM frl_seg_ctrl
                   WHERE entity_num = @EntityNum
                     AND seg_num = @i

		  /* IF not validated AND category responsibility, pull */
                  /* AND separate via RESP.				*/
                  INSERT INTO #frl_seg_desc (SEG_CODE, DEFN_DESC, ACCT_ABBR)
	          SELECT SEG_CODE=substring(ACCT_CODE, @RespStart, @SegLength),
                         DEFN_DESC, ACCT_ABBR
	            FROM RESP
	           WHERE FLX_PRS_OWNER = @ProcessSet
	             AND STRT_CODE = @Structure

                  /* Loop through #frl_seg_desc */
                  SET RowCount 1

                  SELECT @Finished = 0

                  WHILE @Finished = 0
                    BEGIN
                      SELECT @SegCode = SEG_CODE,
                             @DefnDesc = DEFN_DESC,
                             @AcctAbbr = ACCT_ABBR
                        FROM #frl_seg_desc
                      IF @@rowcount <> 0 
                        BEGIN
                          BEGIN tran
                          INSERT INTO frl_seg_desc
                	    (entity_num, seg_num, seg_code, seg_code_desc, 
                             seg_short_desc)
               	          values (@EntityNum, @i, @SegCode, @DefnDesc, @AcctAbbr)

                          SET RowCount 0
                          DELETE #frl_seg_desc
                           WHERE SEG_CODE = @SegCode
                          SET RowCount 1

                          commit tran
                        END
                      else
                        SELECT @Finished = 1
                     END
                  SELECT @RespStart = @RespStart + @SegLength

                END
              SET RowCount 0
            END
        END

      /* IF Natural Accounts TABLE */
      IF @Category = 2
	BEGIN
	  BEGIN tran
	  INSERT INTO frl_seg_desc
	    (entity_num, seg_num, seg_code, seg_code_desc, seg_short_desc)
	    SELECT @EntityNum, @i, ACCT_CODE, DEFN_DESC, ACCT_ABBR
	      FROM ACTC
	     WHERE FLX_PRS_OWNER = @ProcessSet
	       AND STRT_CODE = @Structure
	  commit tran
	END

      SELECT @i = @i + 1
    END
    UPDATE frl_entity
       SET chg_seg_desc = 0
     WHERE entity_num = @EntityNum
END
go
GRANT EXECUTE ON frlBuildSegDesc TO PUBLIC
go

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id('frlBuildGLIX'))
  DROP PROC frlBuildGLIX
go

CREATE PROC frlBuildGLIX @ProcessSet char(8), @Structure char(8), @EntityNum smallint, @EntityCode char(16), @EntityDesc varchar(50)
AS
BEGIN



  DECLARE @MaxSegs tinyint,
	  @i tinyint,
	  @tblID int,
	  @AcctLen tinyint,
	  @SegLen tinyint,
	  @Category tinyint,
	  @CurSegDesc varchar(30),
	  @CurSegSize tinyint,
	  @NatSegNum tinyint,
	  @NatSegDesc varchar(30),
	  @NatSegSize tinyint,
	  @fInNatSeg tinyint,
	  @CompSegNum tinyint,
	  @CompSegDesc varchar(30),
	  @CompSegSize tinyint,
	  @fInCompSeg tinyint,
	  @fInsertSegCtrl tinyint,
	  @SegNum tinyint,
	  @RealSeg tinyint,
	  @KeepDeleting tinyint,
	  @GotNat tinyint,
	  @GotComp tinyint,
	  @SegCtrl tinyint,
	  @ElmCode char(8),
	  @ElmValdte tinyint

  SELECT @AcctLen = 0

  /* Check AND INSERT entity rec */

  IF not exists(SELECT * FROM frl_entity WHERE entity_num = @EntityNum)
    BEGIN
      INSERT INTO frl_entity (entity_num, entity_code, entity_desc, entity_key1, entity_key2, index_built)
	values (@EntityNum, @EntityCode, @EntityDesc, @ProcessSet, @Structure, 0)
    END
  else
    BEGIN
      UPDATE frl_entity
	 SET entity_code = @EntityCode,
	     entity_desc = @EntityDesc,
	     entity_key1 = @ProcessSet,
	     entity_key2 = @Structure,
	     index_built = 0
       WHERE entity_num = @EntityNum
    END

  /* UPDATE seg_ctrl */
  SET RowCount 2500
  SELECT @KeepDeleting = 1
  WHILE @KeepDeleting = 1
  BEGIN
    BEGIN tran
      DELETE FROM frl_seg_desc
       WHERE entity_num = @EntityNum
      IF @@RowCount = 0
	SELECT @KeepDeleting = 0
    commit tran
  END

  SET RowCount 2500
  SELECT @KeepDeleting = 1
  WHILE @KeepDeleting = 1
  BEGIN
    BEGIN tran
      DELETE FROM frl_seg_ctrl
       WHERE entity_num = @EntityNum
      IF @@RowCount = 0
	SELECT @KeepDeleting = 0
    commit tran
  END

  /* Build segment control TABLE */

  /* Find the max segments */
  SELECT @i = 1,
	 @fInNatSeg = 0,
	 @NatSegSize = 0,
	 @fInCompSeg = 0,
	 @CompSegSize = 0,
	 @fInsertSegCtrl = 0,
	 @SegNum = 0,
	 @MaxSegs = max(A.ELM_DSP_ORDER),
	 @NatSegNum = 0,
	 @CompSegNum = 0,
	 @GotNat = 0,
	 @GotComp = 0
    FROM STEL A, ELMT B
   WHERE A.FLX_PRS_OWNER = @ProcessSet
     AND A.STRT_CODE = @Structure
     AND A.ELM_CODE = B.ELM_CODE
     AND A.FLX_PRS_OWNER = B.FLX_PRS_OWNER

  CREATE TABLE #frl_real_segs (new_seg tinyint, old_seg tinyint)

  WHILE @i <= @MaxSegs
    BEGIN
      SELECT @SegCtrl = 0
      SELECT @Category = B.ELM_CATG, @CurSegDesc = B.ELM_DESC, @CurSegSize = B.ELM_SIZE
	FROM STEL A, ELMT B
       WHERE A.FLX_PRS_OWNER = @ProcessSet
	 AND A.STRT_CODE = @Structure
	 AND A.ELM_DSP_ORDER = @i
	 AND A.ELM_CODE = B.ELM_CODE
	 AND A.FLX_PRS_OWNER = B.FLX_PRS_OWNER

      IF @fInNatSeg = 1
        BEGIN
          IF @Category = 2
            BEGIN
              SELECT @NatSegSize = @NatSegSize + @CurSegSize
            END
          ELSE
            BEGIN
              INSERT INTO frl_seg_ctrl values
                (@EntityNum, @NatSegNum, @NatSegDesc, @NatSegSize)
              INSERT #frl_real_segs values (@SegNum, @NatSegNum)
              SELECT @GotNat = 1, @SegCtrl = 1, @fInNatSeg = 0
            END
        END

      IF @fInCompSeg = 1
        BEGIN
          IF @Category = 0
            BEGIN
              SELECT @CompSegSize = @CompSegSize + @CurSegSize
            END
          ELSE
            BEGIN
              INSERT INTO frl_seg_ctrl values
                (@EntityNum, @CompSegNum, @CompSegDesc, @CompSegSize)
              INSERT #frl_real_segs values (@SegNum, @CompSegNum)
              SELECT @GotComp = 1, @SegCtrl = 1, @fInCompSeg = 0
            END
        END

      IF @Category = 2 AND @GotNat = 0
        BEGIN
          IF @fInNatSeg = 0 AND @NatSegNum = 0
            BEGIN
             SELECT @SegNum = @SegNum + 1 
             SELECT @fInsertSegCtrl = 0,
                     @NatSegDesc = @CurSegDesc,
                     @NatSegNum = @SegNum,
                     @fInNatSeg = 1,
                     @NatSegSize = @CurSegSize
            END
        END
      ELSE
        BEGIN
          IF @Category = 0 AND @GotComp = 0
            BEGIN
              IF @fInCompSeg = 0 AND @CompSegNum = 0
	          BEGIN
                    SELECT @SegNum = @SegNum + 1 
	            SELECT @fInsertSegCtrl = 0,
		           @CompSegDesc = @CurSegDesc,
		           @CompSegNum = @SegNum,
		           @fInCompSeg = 1,
                       @CompSegSize = @CurSegSize
	          END
            END
          ELSE
            BEGIN
              SELECT @SegNum = @SegNum + 1
              INSERT INTO frl_seg_ctrl values
                (@EntityNum, @SegNum, @CurSegDesc, @CurSegSize)
              INSERT #frl_real_segs values (@SegNum, @i)
              SELECT @SegCtrl = 1
            END
        END
      
      SELECT @i = @i + 1

    END

    IF @SegCtrl = 0
      BEGIN
	  IF @fInNatSeg = 1
	    BEGIN
	      INSERT INTO frl_seg_ctrl values
		(@EntityNum, @NatSegNum, @NatSegDesc, @NatSegSize)
	      INSERT #frl_real_segs values (@SegNum, @NatSegNum)
	    END
	  else
	    BEGIN
  	      IF @fInCompSeg = 1
	        BEGIN
	          INSERT INTO frl_seg_ctrl values
		    (@EntityNum, @CompSegNum, @CompSegDesc, @CompSegSize)
	          INSERT #frl_real_segs values (@SegNum, @CompSegNum)
	        END
              ELSE
                BEGIN
                  SELECT @SegNum = @SegNum + 1
	          INSERT INTO frl_seg_ctrl values
		    (@EntityNum, @SegNum, @CurSegDesc, @CurSegSize)
	          INSERT #frl_real_segs values (@SegNum, @i-1)
                END
	    END
      END

  SELECT @MaxSegs = @SegNum


  /* Filling in frl_seg_desc */
  exec frlBuildSegDesc @EntityNum, @ProcessSet, @Structure

  SELECT @MaxSegs = max(seg_num),
	 @AcctLen = sum(seg_length)
    FROM frl_seg_ctrl
   WHERE entity_num = @EntityNum

  SELECT @tblID = id
    FROM sysobjects
   WHERE name = 'frl_acct_code'

  /* Add rollup level for flexi */
  IF not exists(SELECT * FROM syscolumns WHERE id = @tblID AND name = 'rollup_level')
    BEGIN
      alter TABLE frl_acct_code
	add rollup_level tinyint NULL
    END

  SELECT @tblID = id
    FROM sysobjects
   WHERE name = 'frl_entity'

  /* Add chg_seg_desc for flexi */
  IF not exists(SELECT * FROM syscolumns WHERE id = @tblID AND name = 'chg_seg_desc')
    BEGIN
      alter TABLE frl_entity
	add chg_seg_desc tinyint NULL
    END

  /* UPDATE entity */
  UPDATE frl_entity
     SET acct_length = @AcctLen,
	 max_segs = @MaxSegs,
	 natural_seg = @NatSegNum,
	 chg_seg_desc = 0
   WHERE entity_num = @EntityNum
	  
  /* Import accounts */
  SET RowCount 2500
  SELECT @KeepDeleting = 1
  WHILE @KeepDeleting = 1
  BEGIN
    BEGIN tran
      DELETE FROM frl_acct_seg
       WHERE entity_num = @EntityNum
      IF @@RowCount = 0
	SELECT @KeepDeleting = 0
    commit tran
  END

  SET RowCount 2500
  SELECT @KeepDeleting = 1
  WHILE @KeepDeleting = 1
  BEGIN
    BEGIN tran
      DELETE FROM frl_acct_code
       WHERE entity_num = @EntityNum
      IF @@RowCount = 0
	SELECT @KeepDeleting = 0
    commit tran
  END

  exec frlUpdateAcctCode @EntityNum, @ProcessSet, @Structure, @NatSegNum, @MaxSegs, 
				@CompSegNum, @EntityCode

  /* UPDATE frl_entity TO reflex built done */
  UPDATE frl_entity
     SET index_built = 1
   WHERE entity_num = @EntityNum

  /* UPDATE statistics */
  UPDATE statistics frl_entity
  UPDATE statistics frl_seg_ctrl
  UPDATE statistics frl_seg_desc
  UPDATE statistics frl_acct_code
  UPDATE statistics frl_acct_seg
 
END
go
GRANT EXECUTE ON frlBuildGLIX TO PUBLIC
go



CREATE TABLE #f
(UnitNo         smallint null,
 Row_no         smallint null,
 account_code   char(64) null,
 pmflag         smallint null,
 negsign        smallint null,
 bal_fwd_flag   smallint null,
 Sequence       int null,
 Int_Code       int null,
 acct_desc      varchar(60) null
)
go

IF EXISTS (SELECT * FROM sysobjects WHERE id = object_id('frlAcctRestrict'))
   DROP procedure frlAcctRestrict
GO

CREATE PROC frlAcctRestrict @ProcessSet char(8), @Structure char(8), @UserCode varchar(20)
AS
BEGIN



  DECLARE @KeepUpdating tinyint,
	  @GLGroupCode varchar(8),
	  @AcctMask char(128)

  SELECT @KeepUpdating = 1

  /* CREATE Temporary mask TABLE */
  SELECT DISTINCT ACCT_MASK INTO #frlAcctMasks
    FROM SLGD A
   WHERE (A.FLX_PRS_OWNER = @ProcessSet AND A.STRT_CODE = @Structure)
     AND A.GL_GROUP_CODE in (SELECT B.GL_GROUP_CODE FROM SLGU B 
			     WHERE (B.FLX_PRS_OWNER = @ProcessSet)
			       AND upper(B.USER_CODE) = @UserCode)
  WHILE @KeepUpdating = 1
    BEGIN
      SET RowCount 1
      SELECT @AcctMask = ACCT_MASK
	FROM #frlAcctMasks

      IF @@RowCount = 0
	SELECT @KeepUpdating = 0
      else
	BEGIN
	  SET RowCount 0
	  BEGIN tran
	  UPDATE #f
	     SET Sequence = abs(Sequence)
	   WHERE account_code like @AcctMask
	  commit tran

	  DELETE #frlAcctMasks
	   WHERE ACCT_MASK = @AcctMask
	END
    END
END
go

GRANT EXECUTE ON frlAcctRestrict TO PUBLIC
go

