/********************************************************************/
/* File: GLIXTBLS.SQL                                               */
/*                                                                  */
/* Description:                                                     */
/*   This file contains SQL statements to create the tables and     */
/*   indexes related to the FRx server-based GL Index.              */
/*                                                                  */ 
/********************************************************************/

if exists(select * from sysobjects where name = 'frl_acct_code') 
	DROP TABLE frl_acct_code
go

CREATE TABLE frl_acct_code
      (acct_id                  int NOT NULL,
       entity_num               smallint NOT NULL,
       acct_code                char(64) NOT NULL,
       acct_type                smallint NULL,
       acct_status              tinyint NULL,
       acct_desc                varchar(100) NULL,
       normal_bal               tinyint NULL,
       bal_sheet_acct           tinyint NULL,
       nat_seg_code                  char(64) NULL,
       rollup_level		tinyint NULL
)
go

grant all on frl_acct_code to public
go

CREATE UNIQUE INDEX XPKfrl_acct_code
  ON frl_acct_code
(
       acct_id,
       entity_num
)
go

CREATE UNIQUE CLUSTERED INDEX XAK1frl_acct_code
  ON frl_acct_code
(
       entity_num,
       acct_code
)
go

CREATE INDEX XAK2frl_acct_code
  ON frl_acct_code
(
       nat_seg_code,
       entity_num
)
go

CREATE INDEX XAK3frl_acct_code
  ON frl_acct_code
(
       acct_type,
       entity_num
)
go

if exists(select * from sysobjects where name = 'frl_seg_desc') 
	DROP TABLE frl_seg_desc
go

CREATE TABLE frl_seg_desc
      (entity_num               smallint NOT NULL,
       seg_num                  tinyint NOT NULL,
       seg_code                 char(20) NOT NULL,
       seg_code_desc            varchar(60) NULL,
       seg_short_desc           varchar(30) NULL
)
go

grant all on frl_seg_desc to public
go

CREATE UNIQUE CLUSTERED INDEX XPKfrl_seg_desc
  ON frl_seg_desc
(
       seg_code,
       seg_num,
       entity_num
)
go

/* We really do not need this one */
CREATE INDEX XIF4frl_seg_desc
  ON frl_seg_desc
(
       entity_num,
       seg_num
)
go

if exists(select * from sysobjects where name = 'frl_seg_ctrl') 
	DROP TABLE frl_seg_ctrl
go

CREATE TABLE frl_seg_ctrl
      (entity_num               smallint NOT NULL,
       seg_num                  tinyint NOT NULL,
       seg_desc                 varchar(30) NULL,
       seg_length               tinyint NULL
)
go

grant all on frl_seg_ctrl to public
go

CREATE UNIQUE CLUSTERED INDEX XPKfrl_seg_ctrl
  ON frl_seg_ctrl
(
       entity_num,
       seg_num
)
go

CREATE INDEX XIF3frl_seg_ctrl
  ON frl_seg_ctrl
(
       entity_num
)
go

if exists(select * from sysobjects where name = 'frl_entity') 
	DROP TABLE frl_entity
go

CREATE TABLE frl_entity
      (entity_num               smallint NOT NULL,
       entity_code              char(16) NULL,
       entity_desc              varchar(50) NULL,
       acct_length              tinyint NULL,
       mask_length              tinyint NULL,
       acct_mask                char(128) NULL,
       max_segs                 tinyint NULL,
       entity_key1              varchar(20) NULL,
       entity_key2              varchar(20) NULL,
       natural_seg              tinyint NULL,
       rollup_level             tinyint NULL,
       chg_seg_desc             tinyint NULL,
       index_built              tinyint NULL
)
go

grant all on frl_entity to public
go

CREATE UNIQUE CLUSTERED INDEX XPKfrl_entity
  ON frl_entity
(
       entity_num
)
go

drop table frl_acct_seg
go

create table frl_acct_seg
	(entity_num int,
         acct_id int,
	 seg_num tinyint,
	 seg_code char(64),
	 acct_code char(64)
	)
go

grant all on frl_acct_seg to public
go

create index frl_acct_seg_idx on frl_acct_seg
	(seg_code,
         seg_num,
         entity_num
	)
go

create index frl_acct_seg_id_idx on frl_acct_seg
	(acct_id,
         entity_num
	)
go

if exists (select name from sysobjects where name = 'frl_script_date')
drop table frl_script_date

create table frl_script_date (
script_name varchar(30),
script_date char(10))

go
insert into frl_script_date
 values('bldglix_SQL2000_70.sql','07/11/2003')

insert into frl_script_date
 values('bldglix_SQL65.sql','07/11/2003')

insert into frl_script_date
 values('glixtbls.sql','07/24/2003')

insert into frl_script_date
 values('accttrig.txt','08/20/2001')

insert into frl_script_date
 values('actctrig.txt','01/10/2003')
go
insert into frl_script_date
 values('comptrig.txt','08/20/2001')
go
insert into frl_script_date
 values('resptrig.txt','08/20/2001')
go

insert into frl_script_date
 values('insnatr.sql','07/05/2000')
go

insert into frl_script_date
 values('tranindx.sql','10/21/1998')
go

insert into frl_script_date
 values('inssegr.sql','02/05/1997')
go








